@@ -4,8 +4,8 @@
 import os
 import unittest
 
-# add the parent directory to the path so the montepylib directory can be found
-os.sys.path.append(os.path.dirname(os.path.abspath('.')))
+# if needed, add the parent directory to the path so the montepylib directory can be found
+# os.sys.path.append(os.path.dirname(os.path.abspath('.')))
 from montepylib.utils import is_string_int
 
 class Test1(unittest.TestCase):
